pub fn idempotency_key(tag: &str, namespace: &str, idem_key: &str) -> StringExpand description
ff:idem:{p:N}:<namespace>:<idempotency_key>
Includes the execution partition hash tag so the key hashes to the same Valkey cluster slot as all other KEYS in the ff_create_execution FCALL.