Module state

Module state 

Structs

StateVector
The full 6+1 dimension execution state vector.

Enums

AttemptLifecycle
Per-attempt lifecycle states.
AttemptState
What is happening at the concrete run-attempt layer?
AttemptType
Why this attempt was created.
BlockingReason
What is the most specific explanation for lack of forward progress?
EligibilityState
Can the execution be claimed for work right now?
LaneState
Lane operational state.
LifecyclePhase
What major phase of existence is this execution in?
OwnershipState
Who, if anyone, is currently allowed to mutate active execution state?
PublicState
Engine-computed user-facing label. Derived from the state vector.
TerminalOutcome
If the execution is terminal, how did it end?