LifecyclePhase

Enum LifecyclePhase 

pub enum LifecyclePhase {
    Submitted,
    Runnable,
    Active,
    Suspended,
    Terminal,
}
What major phase of existence is this execution in?

Variants



Submitted

Accepted by engine, not yet resolved to runnable/delayed. Transient.



Runnable

Eligible or potentially eligible for claiming.



Active

Currently owned by a worker lease and in progress.



Suspended

Intentionally paused, waiting for signal/approval/callback.



Terminal

Execution is finished. No further state transitions except replay.