HandleDecodeError

Enum HandleDecodeError 

#[non_exhaustive]
pub enum HandleDecodeError { Truncated { needed: usize, at: usize, have: usize, }, TrailingBytes { pos: usize, len: usize, }, BadWireVersion { got: u8, }, BadV1Version { got: u8, }, BadBackendTag { got: u8, }, InvalidUtf8 { field: &'static str, }, ParseField { field: &'static str, detail: String, }, }
Typed decode-failure classification. Mapped to EngineError::Validation { kind: Corruption, .. } at the backend boundary via the From impl.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Truncated

Buffer shorter than required by the current read position.

Fields

needed: usize
have: usize


TrailingBytes

Trailing bytes after the last expected field.

Fields

pos: usize
len: usize


BadWireVersion

v2 wire-version byte did not match a supported version.

Fields

got: u8


BadV1Version

v1-path version byte did not match the expected tag.

Fields

got: u8


BadBackendTag

v2 backend-tag byte did not map to a known BackendTag.

Fields

got: u8


InvalidUtf8

A length-prefixed string had invalid UTF-8.

Fields

field: &'static str


ParseField

A parsed id/field failed its own validation (e.g. ExecutionId::parse).

Fields

field: &'static str
detail: String