SignalDeliveryEffect

Enum SignalDeliveryEffect 

#[non_exhaustive]
pub enum SignalDeliveryEffect { Satisfied, Buffered, Deduped, Other(String), }
Effect of a signal delivery on the target waitpoint.

#[non_exhaustive] for future effects (e.g. Throttled, Coalesced).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Satisfied

The signal was delivered and its waitpoint transitioned to satisfied.



Buffered

The signal was buffered against a pending waitpoint.



Deduped

The signal was deduped against an earlier delivery with the same idempotency key.



Other(String)

Effect surfaced by the backend but not recognised by this crate version. Raw string preserved for observability.

Implementations